@@ -1,6 +1,6 @@
 import xcffib
 import struct
-import six
+import io
 MAJOR_VERSION = 1
 MINOR_VERSION = 1
 key = xcffib.ExtensionKey("DAMAGE")
@@ -22,7 +22,7 @@ class BadDamageError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 0))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -50,7 +50,7 @@ class NotifyEvent(xcffib.Event):
         self.geometry = xproto.RECTANGLE(unpacker)
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 0))
         buf.write(struct.pack("=B2xIII", self.level, self.drawable, self.damage, self.timestamp))
         buf.write(self.area.pack() if hasattr(self.area, "pack") else RECTANGLE.synthetic(*self.area).pack())
@@ -72,23 +72,23 @@ class NotifyEvent(xcffib.Event):
 _events[0] = NotifyEvent
 class damageExtension(xcffib.Extension):
     def QueryVersion(self, client_major_version, client_minor_version, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", client_major_version, client_minor_version))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
     def Create(self, damage, drawable, level, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIB3x", damage, drawable, level))
         return self.send_request(1, buf, is_checked=is_checked)
     def Destroy(self, damage, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", damage))
         return self.send_request(2, buf, is_checked=is_checked)
     def Subtract(self, damage, repair, parts, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIII", damage, repair, parts))
         return self.send_request(3, buf, is_checked=is_checked)
     def Add(self, drawable, region, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", drawable, region))
         return self.send_request(4, buf, is_checked=is_checked)
 xcffib._add_ext(key, damageExtension, _events, _errors)
