@@ -80,8 +80,8 @@ class ClientIdValue(xcffib.Struct):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = io.BytesIO()
-        buf.write(struct.pack("=I", self.length))
         buf.write(self.spec.pack() if hasattr(self.spec, "pack") else ClientIdSpec.synthetic(*self.spec).pack())
+        buf.write(struct.pack("=I", self.length))
         buf.write(xcffib.pack_list(self.value, "I"))
         return buf.getvalue()
     @classmethod
@@ -121,8 +121,10 @@ class ResourceSizeSpec(xcffib.Struct):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = io.BytesIO()
-        buf.write(struct.pack("=III", self.bytes, self.ref_count, self.use_count))
         buf.write(self.spec.pack() if hasattr(self.spec, "pack") else ResourceIdSpec.synthetic(*self.spec).pack())
+        buf.write(struct.pack("=I", self.bytes))
+        buf.write(struct.pack("=I", self.ref_count))
+        buf.write(struct.pack("=I", self.use_count))
         return buf.getvalue()
     @classmethod
     def synthetic(cls, spec, bytes, ref_count, use_count):
@@ -145,8 +147,8 @@ class ResourceSizeValue(xcffib.Struct):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = io.BytesIO()
-        buf.write(struct.pack("=I", self.num_cross_references))
         buf.write(self.size.pack() if hasattr(self.size, "pack") else ResourceSizeSpec.synthetic(*self.size).pack())
+        buf.write(struct.pack("=I", self.num_cross_references))
         buf.write(xcffib.pack_list(self.cross_references, ResourceSizeSpec))
         return buf.getvalue()
     @classmethod
